//index.js
import { systemFetch } from '../../api/fetch';
const md5 = require('blueimp-md5');
//获取应用实例
import { IMyApp } from '../../app';
const app = getApp<IMyApp>();

Page({
  onLoad(option) {
    console.log(option);
    if (app.globalData.token) {
      this.tokenLoagin();
    } else if (option.logout) {
      // this.codeLogin();
    } else {
      this.codeLogin();
    }
  },
  data: {
    account: '',
    pwd: '',
    showPassword: false,
  },
  togglePassword() {
    this.setData!({
      showPassword: !this.data.showPassword,
    });
  },
  validateLoginData() {
    const { account, pwd } = this.data;
    if (!account) {
      wx.showToast({
        title: '请输入账户',
        icon: 'none',
      });
      return;
    }
    if (!pwd) {
      wx.showToast({
        title: '请输入密码',
        icon: 'none',
      });
      return;
    }
    return true;
  },
  tokenLoagin() {
    wx.login({
      success: res => {
        if (res.code) {
          const code = res.code;

          wx.showLoading({ title: '登陆中' });
          systemFetch({
            url: '/login/verifyCode',
          })
            .then((res: wx.RequestSuccessCallbackResult) => {
              console.log(res);
              return {
                code: res.data.verifyCode,
                cookie: res.header['Set-Cookie'],
              };
            })
            .then(({ cookie }: { code: string; cookie: string }) =>
              systemFetch({
                url: '/boss/login',
                method: 'POST',
                header: {
                  cookie: cookie,
                },
                data: {
                  code,
                  token: app.globalData.token,
                },
              }),
            )
            .then(res => {
              console.log(res);
              const {
                token,
                data: { userInfo, userRoles },
              } = res;
              app.globalData.token = token;
              app.globalData.userInfo = userInfo;
              app.globalData.userRoles = userRoles.length
                ? userRoles[0].childs
                : [];
              wx.hideLoading();
              wx.redirectTo({
                url: '/pages/homeAndReport/homeAndReport',
              });
            })
            .catch(err => {
              console.log(err);
              wx.hideLoading();
              wx.showToast({
                title: err.errMsg,
                icon: 'none',
              });
            });
        }
      },
    });
  },
  loginHandle() {
    console.log(app.globalData);
    if (this.validateLoginData()) {
      const { account, pwd } = this.data;
      console.log(account, pwd);
      systemFetch({
        url: '/boss/login/init/data',
        method: 'GET',
      })
        .then(res => {
          console.log(res);
          return res.templates;
        })
        .catch(err => {
          return;
        })
        .then(ids => {
          let tmplIds =
            ids && ids.length ? ids.map(item => item.templateId) : [];
          wx.requestSubscribeMessage({
            tmplIds: tmplIds,
            success(res) {
              console.log('in success', res);
            },
            fail(res) {
              console.log('in fail', res);
            },
            complete(res) {
              console.log('in complete', res);
              wx.login({
                success: res => {
                  if (res.code) {
                    const code = res.code;
                    wx.showLoading({ title: '' });
                    systemFetch({
                      url: '/login/verifyCode',
                    })
                      .then((res: wx.RequestSuccessCallbackResult) => {
                        console.log(res);
                        return {
                          verifyCode: res.data.verifyCode,
                          cookie: res.header['Set-Cookie'],
                        };
                      })
                      .then(
                        ({
                          verifyCode,
                          cookie,
                        }: {
                          verifyCode: string;
                          cookie: string;
                        }) => {
                          let mixpwd = md5(pwd);
                          return systemFetch({
                            url: '/boss/login',
                            method: 'POST',
                            header: {
                              cookie: cookie,
                            },
                            data: {
                              code,
                              account,
                              pwd: mixpwd,
                              varifyCode: verifyCode,
                            },
                          });
                        },
                      )
                      .then(res => {
                        console.log(res);
                        const {
                          token,
                          data: { userInfo, userRoles },
                        } = res;
                        app.globalData.token = token;
                        app.globalData.userInfo = userInfo;
                        app.globalData.userRoles = userRoles.length
                          ? userRoles[0].childs
                          : [];
                        try {
                          wx.setStorageSync('token', token);
                        } catch (error) {}
                        wx.hideLoading();
                        wx.redirectTo({
                          url: '/pages/homeAndReport/homeAndReport',
                        });
                      })
                      .catch(err => {
                        console.log(err);
                        wx.hideLoading();
                        wx.showToast({
                          title: err.errMsg,
                          icon: 'none',
                        });
                      });
                  } else {
                    wx.showToast({
                      title: '登录获取code失败',
                      icon: 'none',
                    });
                  }
                },
              });
            },
          });
        })
        .catch(err => {
          console.log(err);
        });
    }
    // fetch()
    // wx.redirectTo({
    //   url: '/pages/home/home'
    // })
  },
  codeLogin() {
    wx.login({
      success: res => {
        if (res.code) {
          const code = res.code;
          systemFetch({
            url: '/boss/login',
            method: 'POST',
            data: {
              code,
            },
          })
            .then(res => {
              console.log(res);
              const {
                token,
                data: { userInfo, userRoles },
              } = res;
              app.globalData.token = token;
              app.globalData.userInfo = userInfo;
              app.globalData.userRoles = userRoles.length
                ? userRoles[0].childs
                : [];
              try {
                wx.setStorageSync('token', token);
              } catch (error) {}
              wx.hideLoading();
              wx.redirectTo({
                url: '/pages/homeAndReport/homeAndReport',
              });
            })
            .catch(err => {
              console.log(err);
              wx.hideLoading();
              wx.showToast({
                title: err.errMsg,
                icon: 'none',
              });
            });
        } else {
          wx.showToast({
            title: '登录获取code失败',
            icon: 'none',
          });
        }
      },
    });
  },
  nameInputHandle(e) {
    const value = e.detail.value;
    this.updateInputValue('account', value);
  },
  passwardInoutHandle(e) {
    const value = e.detail.value;
    this.updateInputValue('pwd', value);
  },
  updateInputValue(key: string, value: string) {
    this.setData!({
      [key]: value,
    });
  },
});
